@@ -1,5 +1,7 @@
 """Module for the automations and business logic of XKNX."""
 # flake8: noqa
+from .connection_manager import ConnectionManager
+from .connection_state import XknxConnectionState
 from .payload_reader import PayloadReader
 from .state_updater import StateUpdater
 from .telegram_queue import TelegramQueue
