@@ -7,11 +7,14 @@ The module will
 * ... check if received telegrams have the correct group address.
 * ... store the received telegram for further processing.
 """
+from __future__ import annotations
+
 import asyncio
 import logging
-from typing import TYPE_CHECKING, Optional
+from typing import TYPE_CHECKING
 
-from xknx.telegram import GroupAddress, Telegram
+from xknx.telegram import Telegram
+from xknx.telegram.address import GroupAddress, InternalGroupAddress
 from xknx.telegram.apci import GroupValueRead, GroupValueResponse, GroupValueWrite
 
 if TYPE_CHECKING:
@@ -24,27 +27,30 @@ class ValueReader:
     """Class for reading the value of a specific KNX group address from KNX bus."""
 
     def __init__(
-        self, xknx: "XKNX", group_address: GroupAddress, timeout_in_seconds: float = 2.0
+        self,
+        xknx: XKNX,
+        group_address: GroupAddress | InternalGroupAddress,
+        timeout_in_seconds: float = 2.0,
     ):
         """Initialize ValueReader class."""
         self.xknx = xknx
-        self.group_address: GroupAddress = group_address
-        self.response_received_or_timeout = asyncio.Event()
-        self.success: bool = False
+        self.group_address: GroupAddress | InternalGroupAddress = group_address
+        self.response_received_event = asyncio.Event()
         self.timeout_in_seconds: float = timeout_in_seconds
-        self.received_telegram: Optional[Telegram] = None
+        self.received_telegram: Telegram | None = None
 
-    async def read(self) -> Optional[Telegram]:
+    async def read(self) -> Telegram | None:
         """Send group read and wait for response."""
         cb_obj = self.xknx.telegram_queue.register_telegram_received_cb(
             self.telegram_received,
             group_addresses=[self.group_address],
+            match_for_outgoing=True,
         )
         await self.send_group_read()
 
         try:
             await asyncio.wait_for(
-                self.response_received_or_timeout.wait(),
+                self.response_received_event.wait(),
                 timeout=self.timeout_in_seconds,
             )
         except asyncio.TimeoutError:
@@ -53,13 +59,13 @@ class ValueReader:
                 self.timeout_in_seconds,
                 self.group_address,
             )
+        else:
+            return self.received_telegram
         finally:
             # cleanup to not leave callbacks (for asyncio.CancelledError)
             self.xknx.telegram_queue.unregister_telegram_received_cb(cb_obj)
 
-        if not self.success:
-            return None
-        return self.received_telegram
+        return None
 
     async def send_group_read(self) -> None:
         """Send group read."""
@@ -73,6 +79,5 @@ class ValueReader:
         if telegram.destination_address == self.group_address and isinstance(
             telegram.payload, (GroupValueResponse, GroupValueWrite)
         ):
-            self.success = True
             self.received_telegram = telegram
-            self.response_received_or_timeout.set()
+            self.response_received_event.set()
