@@ -104,6 +104,4 @@ class Switch(Device):
 
     def __str__(self) -> str:
         """Return object as readable string."""
-        return '<Switch name="{}" switch={} />'.format(
-            self.name, self.switch.group_addr_str()
-        )
+        return f'<Switch name="{self.name}" switch={self.switch.group_addr_str()} />'
