@@ -67,7 +67,7 @@ class DPTControlStepCode(DPTBase, ABC):
         # TODO: use Tuple or Named Tuple instead of Dict[str, int] to account for bool control
         if not isinstance(value, dict):
             raise ConversionError(
-                "Cant serialize %s; invalid value type" % cls.__name__, value=value
+                f"Cant serialize {cls.__name__}; invalid value type", value=value
             )
 
         try:
@@ -75,12 +75,12 @@ class DPTControlStepCode(DPTBase, ABC):
             step_code = value["step_code"]
         except KeyError:
             raise ConversionError(
-                "Cant serialize %s; invalid keys" % cls.__name__, value=value
+                f"Cant serialize {cls.__name__}; invalid keys", value=value
             )
 
         if not cls._test_values(step_code):
             raise ConversionError(
-                "Cant serialize %s; invalid values" % cls.__name__, value=value
+                f"Cant serialize {cls.__name__}; invalid values", value=value
             )
 
         return (cls._encode(control, step_code),)
@@ -89,7 +89,7 @@ class DPTControlStepCode(DPTBase, ABC):
     def from_knx(cls, raw: tuple[int, ...]) -> Any:
         """Parse/deserialize from KNX/IP raw data."""
         if not isinstance(raw, tuple) or not cls._test_boundaries(raw[0]):
-            raise ConversionError("Cant parse %s" % cls.__name__, raw=raw)
+            raise ConversionError(f"Cant parse {cls.__name__}", raw=raw)
 
         control, step_code = cls._decode(raw[0])
 
@@ -143,7 +143,7 @@ class DPTControlStepwise(DPTControlStepCode):
     def to_knx(cls, value: int | dict[str, int]) -> tuple[int]:
         """Serialize to KNX/IP raw data."""
         if not isinstance(value, int):
-            raise ConversionError("Cant serialize %s" % cls.__name__, value=value)
+            raise ConversionError(f"Cant serialize {cls.__name__}", value=value)
 
         return super().to_knx(cls._from_increment(value))
 
@@ -209,7 +209,7 @@ class DPTControlStartStop(DPTControlStepCode):
             control = 0
             step_code = 0
         else:
-            raise ConversionError("Cant serialize %s" % cls.__name__, value=value)
+            raise ConversionError(f"Cant serialize {cls.__name__}", value=value)
 
         values = {"control": control, "step_code": step_code}
         return super().to_knx(values)
